import { UserData, type z } from '@mongodb-js/compass-user-data';
import { RecentQuerySchema, FavoriteQuerySchema } from './query-storage-schema';
import type { FavoriteQueryStorage, RecentQueryStorage } from './query-storage';
export type QueryStorageOptions = {
    basepath?: string;
};
export declare abstract class CompassQueryStorage<T extends typeof RecentQuerySchema> {
    protected readonly folder: string;
    protected readonly options: QueryStorageOptions;
    protected readonly userData: UserData<T>;
    constructor(schemaValidator: T, folder: string, options: QueryStorageOptions);
    loadAll(namespace?: string): Promise<z.output<T>[]>;
    updateAttributes(id: string, data: Partial<z.input<T>>): Promise<z.output<T>>;
    delete(id: string): Promise<boolean>;
}
export declare class CompassRecentQueryStorage extends CompassQueryStorage<typeof RecentQuerySchema> implements RecentQueryStorage {
    private readonly maxAllowedQueries;
    constructor(options?: QueryStorageOptions);
    saveQuery(data: Omit<z.input<typeof RecentQuerySchema>, '_id' | '_lastExecuted'>): Promise<void>;
}
export declare class CompassFavoriteQueryStorage extends CompassQueryStorage<typeof FavoriteQuerySchema> implements FavoriteQueryStorage {
    constructor(options?: QueryStorageOptions);
    saveQuery(data: Omit<z.input<typeof FavoriteQuerySchema>, '_id' | '_lastExecuted' | '_dateModified' | '_dateSaved'>): Promise<void>;
}
//# sourceMappingURL=compass-query-storage.d.ts.map