"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PipelineSchema = void 0;
const compass_user_data_1 = require("@mongodb-js/compass-user-data");
const compass_editor_1 = require("@mongodb-js/compass-editor");
function stageToString(operator, value, disabled) {
    const str = `{
  ${operator}: ${value}
}`;
    if (!disabled) {
        return str;
    }
    return str
        .split('\n')
        .map((line) => `// ${line}`)
        .join('\n');
}
function savedPipelineToText(pipeline) {
    const stages = pipeline?.map(({ stageOperator, isEnabled, stage }) => {
        return stageToString(stageOperator, stage, !isEnabled);
    }) ?? [];
    const source = `[\n${stages.join(',\n')}\n]`;
    try {
        return (0, compass_editor_1.prettify)(source);
    }
    catch {
        return source;
    }
}
exports.PipelineSchema = compass_user_data_1.z.preprocess((val) => {
    const { pipeline: legacyPipelineArray, pipelineText, ...rest } = val;
    return {
        ...rest,
        pipelineText: pipelineText ?? savedPipelineToText(legacyPipelineArray),
    };
}, compass_user_data_1.z.object({
    id: compass_user_data_1.z.string(),
    name: compass_user_data_1.z.string(),
    namespace: compass_user_data_1.z.string(),
    comments: compass_user_data_1.z.boolean().optional(),
    autoPreview: compass_user_data_1.z.boolean().optional(),
    collationString: compass_user_data_1.z.string().optional(),
    host: compass_user_data_1.z.string().nullable().optional(),
    pipelineText: compass_user_data_1.z.string(),
    lastModified: compass_user_data_1.z
        .number()
        .transform((x) => new Date(x))
        .optional(),
}));
//# sourceMappingURL=pipeline-storage-schema.js.map